yog/dag/models

⚠️ Deprecated Module

This module has been renamed to yog/dag/model (singular). Please update your imports to use yog/dag/model instead.

This module will be removed in a future version.

Types

pub type Dag(node_data, edge_data) =
  model.Dag(node_data, edge_data)
pub type DagError =
  model.DagError

Values

pub fn add_edge(
  dag: model.Dag(n, e),
  from src: Int,
  to dst: Int,
  with weight: e,
) -> Result(model.Dag(n, e), model.DagError)

Deprecated: Use yog/dag/model.add_edge instead

Adds an edge to the DAG.

@deprecated Use yog/dag/model.add_edge instead

pub fn add_node(
  dag: model.Dag(n, e),
  id: Int,
  data: n,
) -> model.Dag(n, e)

Deprecated: Use yog/dag/model.add_node instead

Adds a node to the DAG.

@deprecated Use yog/dag/model.add_node instead

pub fn from_graph(
  graph: model.Graph(n, e),
) -> Result(model.Dag(n, e), model.DagError)

Deprecated: Use yog/dag/model.from_graph instead

Attempts to create a Dag from a regular Graph.

@deprecated Use yog/dag/model.from_graph instead

pub fn remove_edge(
  dag: model.Dag(n, e),
  from src: Int,
  to dst: Int,
) -> model.Dag(n, e)

Deprecated: Use yog/dag/model.remove_edge instead

Removes an edge from the DAG.

@deprecated Use yog/dag/model.remove_edge instead

pub fn remove_node(
  dag: model.Dag(n, e),
  id: Int,
) -> model.Dag(n, e)

Deprecated: Use yog/dag/model.remove_node instead

Removes a node and all its connected edges from the DAG.

@deprecated Use yog/dag/model.remove_node instead

pub fn to_graph(dag: model.Dag(n, e)) -> model.Graph(n, e)

Deprecated: Use yog/dag/model.to_graph instead

Unwraps a Dag back into a regular Graph.

@deprecated Use yog/dag/model.to_graph instead

Search Document